@@ -4,4 +4,7 @@ Criado por Érick Ghuron
 Jupiterweb API
 """
 
-from .api import buscar_disciplina_por_codigo, buscar_disciplina_por_nome
\ No newline at end of file
+from .api import buscar_disciplina_por_codigo, buscar_disciplina_por_nome
+
+__author__ = 'Erick Ghuron'
+__version__ = '1.2.0'
\ No newline at end of file
